#ifndef VIDEOUTILS_H
#define VIDEOUTILS_H


/*
      videoutils.h
      (c) 2004 Xavier Hervy
      Class that allow to run player + class for ui in video gallery
      Some code provide from videotree, videobrowser and videogallery
      then thanks to others contributors
*/
#include <mythtv/mythdialogs.h>
#include <metadata.h>
#include <videofilter.h>
#include <mythtv/uilistbtntype.h>

class VideoPlayerPopup;

class VideoPlayer : public QObject
{
    Q_OBJECT
    public :
           VideoPlayer(QSqlDatabase * db,MythDialog * owner, unsigned int idmetadata);
           VideoPlayer(QSqlDatabase * db,MythDialog * owner, QString filename);
           ~VideoPlayer();
           void Play();
    protected slots :
           void slotDoCancel(void);
           void slotDoRetry(void);
    signals :
           void playerTerminated(void);
           void playerNextFile(void);

    private :
           void cancelPopup();
           QString getCommand(QString path);
           void PlayNext(void);
           Metadata * curitem;
           VideoPlayerPopup * popup;
           MythDialog * owner;
           QSqlDatabase * db;
           QTime playing_time;
};

class VideoPlayerPopup : public MythPopupBox
{
  Q_OBJECT
  public :
      VideoPlayerPopup(MythMainWindow * parent, const char *name)
                      :MythPopupBox(parent,name){};
      virtual bool onMediaEvent(MythMediaDevice * mediadevice);

      signals :
           void retry(void);
};

class TreeGroupByItem : public UIListGenericTree
{
    public :
           TreeGroupByItem(UIListGenericTree * parent, 
                                 VideoFilterCapability * lcap,
                                 QValueList <VideoFilterCapability*> lgroupby);
           TreeGroupByItem(UIListGenericTree * parent,QString name); 
            virtual ~TreeGroupByItem(){};
           QValueList <VideoFilterCapability*> GroupBy(){return groupby;};
    private :
           QValueList <VideoFilterCapability*> groupby;
};

class TreeFilterCapabilityItem : public UIListGenericTree
{
    public :
           TreeFilterCapabilityItem(UIListGenericTree * parent, 
                                 VideoFilterCapability * lcap);
            virtual ~TreeFilterCapabilityItem(){};
            VideoFilterCapability * getCapability (){return capability;};
            void updateText();
    private :
            VideoFilterCapability * capability;
};

class TreeFilterCapabilityValueItem : public UIListGenericTree
{
    public :
           TreeFilterCapabilityValueItem(UIListGenericTree * parent, 
                                 VideoFilterCapability * lcap,
                                 VideoFilterCapabilityValue * lval);
            virtual ~TreeFilterCapabilityValueItem(){};
            VideoFilterCapability * getCapability (){return capability;};
            VideoFilterCapabilityValue * getValue (){return value;};
    private :
            VideoFilterCapability * capability;
            VideoFilterCapabilityValue * value;
};

class TreeActionItem : public UIListGenericTree
{
    public :
           TreeActionItem(UIListGenericTree * parent, 
                                 QString name);
            virtual ~TreeActionItem(){};
            void setAction(void* laction);
            void *getAction();
    private :
            void * m_action;
};


#endif
